@@ -1,9 +1,13 @@
 from scierra.utils.utils import rndstr
 from scierra.utils.utils import gen_name
 from scierra.utils.utils import working_dir
+from scierra.utils.utils import str_equal
 from scierra.utils.utils import count
 from scierra.utils.utils import skip_whitespaces
+from scierra.utils.utils import cross_whitespaces
 from scierra.utils.utils import count_fors
+from scierra.utils.utils import min_semis
+from scierra.utils.utils import isblock
 from scierra.utils.utils import empty_couts
 from scierra.utils.utils import replace_string
 from scierra.utils.utils import replace_comment
